uhugo.post_install.detect_providers — uHugo 1.1.10 documentation

# uhugo.post_install.detect_providers

class uhugo.post_install.detect_providers.Provider(*, name: str | None = None, project: str | None = None, file_name: str | None = None, api_key: str | None = None, account_id: str | None = None, email_address: str | None = None, path: str | None = None)

  Bases: `BaseModel`

  This holds the information about the provider

  Create a new model by parsing and validating input data from keyword arguments.

  Raises [ValidationError][pydantic_core.ValidationError] if the input data cannot be validated to form a valid model.

  __init__ uses __pydantic_self__ instead of the more common self for the first arg to allow self as a field name.

  account_id: str | None
  api_key: str | None
  classmethod construct(_fields_set: set[str] | None = None, **values: Any) → Model
  copy(*, include: AbstractSetIntStr | MappingIntStrAny | None = None, exclude: AbstractSetIntStr | MappingIntStrAny | None = None, update: Dict[str, Any] | None = None, deep: bool = False) → Model

    Returns a copy of the model.

    !!! warning “Deprecated”

      This method is now deprecated; use model_copy instead.

    If you need include or exclude, use:

    ``py data = self.model_dump(include=include, exclude=exclude, round_trip=True) data = {**data, **(update or {})} copied = self.model_validate(data) ``

    Parameters:

      - include – Optional set or mapping specifying which fields to include in the copied model.

      - exclude – Optional set or mapping specifying which fields to exclude in the copied model.

      - update – Optional dictionary of field-value pairs to override field values in the copied model.

      - deep – If True, the values of fields that are Pydantic models will be deep copied.

    Returns:

      A copy of the model with included, excluded and updated fields as specified.

  dict(*, include: IncEx = None, exclude: IncEx = None, by_alias: bool = False, exclude_unset: bool = False, exclude_defaults: bool = False, exclude_none: bool = False) → Dict[str, Any]
  email_address: str | None
  file_name: str | None
  classmethod from_orm(obj: Any) → Model
  json(*, include: IncEx = None, exclude: IncEx = None, by_alias: bool = False, exclude_unset: bool = False, exclude_defaults: bool = False, exclude_none: bool = False, encoder: Callable[[Any], Any] | None = PydanticUndefined, models_as_dict: bool = PydanticUndefined, **dumps_kwargs: Any) → str
  property model_computed_fields: dict[str, ComputedFieldInfo]

    Get the computed fields of this model instance.

    Returns:

      A dictionary of computed field names and their corresponding ComputedFieldInfo objects.

  model_config: ClassVar[ConfigDict] = {}

    Configuration for the model, should be a dictionary conforming to [ConfigDict][pydantic.config.ConfigDict].

  classmethod model_construct(_fields_set: set[str] | None = None, **values: Any) → Model

    Creates a new instance of the Model class with validated data.

    Creates a new model setting __dict__ and __pydantic_fields_set__ from trusted or pre-validated data. Default values are respected, but no other validation is performed. Behaves as if Config.extra = ‘allow’ was set since it adds all passed values

    Parameters:

      - _fields_set – The set of field names accepted for the Model instance.

      - values – Trusted or pre-validated data dictionary.

    Returns:

      A new instance of the Model class with validated data.

  model_copy(*, update: dict[str, Any] | None = None, deep: bool = False) → Model

    Usage docs: https://docs.pydantic.dev/2.2/usage/serialization/#model_copy

    Returns a copy of the model.

    Parameters:

      - update – Values to change/add in the new model. Note: the data is not validated before creating the new model. You should trust this data.

      - deep – Set to True to make a deep copy of the model.

    Returns:

      New model instance.

  model_dump(*, mode: Literal['json', 'python'] | str = 'python', include: IncEx = None, exclude: IncEx = None, by_alias: bool = False, exclude_unset: bool = False, exclude_defaults: bool = False, exclude_none: bool = False, round_trip: bool = False, warnings: bool = True) → dict[str, Any]

    Usage docs: https://docs.pydantic.dev/2.2/usage/serialization/#modelmodel_dump

    Generate a dictionary representation of the model, optionally specifying which fields to include or exclude.

    Parameters:

      - mode – The mode in which to_python should run. If mode is ‘json’, the dictionary will only contain JSON serializable types. If mode is ‘python’, the dictionary may contain any Python objects.

      - include – A list of fields to include in the output.

      - exclude – A list of fields to exclude from the output.

      - by_alias – Whether to use the field’s alias in the dictionary key if defined.

      - exclude_unset – Whether to exclude fields that are unset or None from the output.

      - exclude_defaults – Whether to exclude fields that are set to their default value from the output.

      - exclude_none – Whether to exclude fields that have a value of None from the output.

      - round_trip – Whether to enable serialization and deserialization round-trip support.

      - warnings – Whether to log warnings when invalid fields are encountered.

    Returns:

      A dictionary representation of the model.

  model_dump_json(*, indent: int | None = None, include: IncEx = None, exclude: IncEx = None, by_alias: bool = False, exclude_unset: bool = False, exclude_defaults: bool = False, exclude_none: bool = False, round_trip: bool = False, warnings: bool = True) → str

    Usage docs: https://docs.pydantic.dev/2.2/usage/serialization/#modelmodel_dump_json

    Generates a JSON representation of the model using Pydantic’s to_json method.

    Parameters:

      - indent – Indentation to use in the JSON output. If None is passed, the output will be compact.

      - include – Field(s) to include in the JSON output. Can take either a string or set of strings.

      - exclude – Field(s) to exclude from the JSON output. Can take either a string or set of strings.

      - by_alias – Whether to serialize using field aliases.

      - exclude_unset – Whether to exclude fields that have not been explicitly set.

      - exclude_defaults – Whether to exclude fields that have the default value.

      - exclude_none – Whether to exclude fields that have a value of None.

      - round_trip – Whether to use serialization/deserialization between JSON and class instance.

      - warnings – Whether to show any warnings that occurred during serialization.

    Returns:

      A JSON string representation of the model.

  property model_extra: dict[str, Any] | None

    Get extra fields set during validation.

    Returns:

      A dictionary of extra fields, or None if config.extra is not set to “allow”.

  model_fields: ClassVar[dict[str, FieldInfo]] = {'account_id': FieldInfo(annotation=Union[str, NoneType], required=False), 'api_key': FieldInfo(annotation=Union[str, NoneType], required=False), 'email_address': FieldInfo(annotation=Union[str, NoneType], required=False), 'file_name': FieldInfo(annotation=Union[str, NoneType], required=False), 'name': FieldInfo(annotation=Union[str, NoneType], required=False), 'path': FieldInfo(annotation=Union[str, NoneType], required=False), 'project': FieldInfo(annotation=Union[str, NoneType], required=False)}

    Metadata about the fields defined on the model, mapping of field names to [FieldInfo][pydantic.fields.FieldInfo].

    This replaces Model.__fields__ from Pydantic V1.

  property model_fields_set: set[str]

    Returns the set of fields that have been set on this model instance.

    Returns:

      A set of strings representing the fields that have been set,

        i.e. that were not filled from defaults.

  classmethod model_json_schema(by_alias: bool = True, ref_template: str = '#/$defs/{model}', schema_generator: type[~pydantic.json_schema.GenerateJsonSchema] = <class 'pydantic.json_schema.GenerateJsonSchema'>, mode: ~typing.Literal['validation', 'serialization'] = 'validation') → dict[str, Any]

    Generates a JSON schema for a model class.

    Parameters:

      - by_alias – Whether to use attribute aliases or not.

      - ref_template – The reference template.

      - schema_generator – To override the logic used to generate the JSON schema, as a subclass of GenerateJsonSchema with your desired modifications

      - mode – The mode in which to generate the schema.

    Returns:

      The JSON schema for the given model class.

  classmethod model_parametrized_name(params: tuple[type[Any], ...]) → str

    Compute the class name for parametrizations of generic classes.

    This method can be overridden to achieve a custom naming scheme for generic BaseModels.

    Parameters:

      params – Tuple of types of the class. Given a generic class Model with 2 type variables and a concrete model Model[str, int], the value (str, int) would be passed to params.

    Returns:

      String representing the new class where params are passed to cls as type variables.

    Raises:

      TypeError – Raised when trying to generate concrete names for non-generic models.

  model_post_init(_BaseModel__context: Any) → None

    Override this method to perform additional initialization after __init__ and model_construct. This is useful if you want to do some validation that requires the entire model to be initialized.

  classmethod model_rebuild(*, force: bool = False, raise_errors: bool = True, _parent_namespace_depth: int = 2, _types_namespace: dict[str, Any] | None = None) → bool | None

    Try to rebuild the pydantic-core schema for the model.

    This may be necessary when one of the annotations is a ForwardRef which could not be resolved during the initial attempt to build the schema, and automatic rebuilding fails.

    Parameters:

      - force – Whether to force the rebuilding of the model schema, defaults to False.

      - raise_errors – Whether to raise errors, defaults to True.

      - _parent_namespace_depth – The depth level of the parent namespace, defaults to 2.

      - _types_namespace – The types namespace, defaults to None.

    Returns:

      Returns None if the schema is already “complete” and rebuilding was not required. If rebuilding _was_ required, returns True if rebuilding was successful, otherwise False.

  classmethod model_validate(obj: Any, *, strict: bool | None = None, from_attributes: bool | None = None, context: dict[str, Any] | None = None) → Model

    Validate a pydantic model instance.

    Parameters:

      - obj – The object to validate.

      - strict – Whether to raise an exception on invalid fields.

      - from_attributes – Whether to extract data from object attributes.

      - context – Additional context to pass to the validator.

    Raises:

      ValidationError – If the object could not be validated.

    Returns:

      The validated model instance.

  classmethod model_validate_json(json_data: str | bytes | bytearray, *, strict: bool | None = None, context: dict[str, Any] | None = None) → Model

    Validate the given JSON data against the Pydantic model.

    Parameters:

      - json_data – The JSON data to validate.

      - strict – Whether to enforce types strictly.

      - context – Extra variables to pass to the validator.

    Returns:

      The validated Pydantic model.

    Raises:

      ValueError – If json_data is not a JSON string.

  name: str | None
  classmethod parse_file(path: str | Path, *, content_type: str | None = None, encoding: str = 'utf8', proto: _deprecated_parse.Protocol | None = None, allow_pickle: bool = False) → Model
  classmethod parse_obj(obj: Any) → Model
  classmethod parse_raw(b: str | bytes, *, content_type: str | None = None, encoding: str = 'utf8', proto: _deprecated_parse.Protocol | None = None, allow_pickle: bool = False) → Model
  path: str | None
  project: str | None
  classmethod schema(by_alias: bool = True, ref_template: str = '#/$defs/{model}') → Dict[str, Any]
  classmethod schema_json(*, by_alias: bool = True, ref_template: str = '#/$defs/{model}', **dumps_kwargs: Any) → str
  classmethod update_forward_refs(**localns: Any) → None
  classmethod validate(value: Any) → Model

uhugo.post_install.detect_providers.check_hugo_file() → Provider

  Checks for `config.yaml` or `config.toml`, if exists then it checks for `uhugo` key

  Return Provider:

    An object with `name` and `file_name`

uhugo.post_install.detect_providers.check_providers_fs() → List[Provider]

  Checks file system for any providers that matches the list

  Returns:

    A Provider